:mod:`whisk.log`
================

.. py:module:: whisk.log

.. autoapi-nested-parse::

   Module for setting up logging.



Module Contents
---------------


.. data:: LOG_LEVELS
   

   

.. data:: LOG_FORMATS
   

   

.. function:: configure_logger(stream_level='DEBUG', log_file=None)

   Configure logging for whisk.
   Set up logging to stdout with given level. If ``log_file`` is given set
   up logging to file with DEBUG level.


